/*
Copyright (c) 2002-2011 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/ 


#ifndef __GFXBITBLITVIEW_h__
#define __GFXBITBLITVIEW_h__

// INCLUDES
#include <coecntrl.h>
#include "CGfxTimer.h"

// CLASS DECLARATION
class CGfxBitBlitView : public CCoeControl, public MGfxTimerCallBack
	{
	public: // New methods

		/**
		* NewL.
		* Two-phased constructor.
		* Create a CGfxDirectScreenBitmapView object, which will draw itself to aRect.
		* @param aRect The rectangle this view will be drawn to.
		* @return a pointer to the created instance of CGfxDirectScreenBitmapView.
		*/
		static CGfxBitBlitView* NewL( const TRect& aRect );

		/**
		* NewLC.
		* Two-phased constructor.
		* Create a CGfxDirectScreenBitmapView object, which will draw itself
		* to aRect.
		* @param aRect Rectangle this view will be drawn to.
		* @return A pointer to the created instance of CGfxDirectScreenBitmapView.
		*/
		static CGfxBitBlitView* NewLC( const TRect& aRect );

		/**
		* ~CGfxDirectScreenBitmapView
		* Virtual Destructor.
		*/
		virtual ~CGfxBitBlitView();

// from MGfxTimerCallBack
		virtual void GfxTimerFiredL(TInt aId);
		
	public:
		void StartL();
		void StopL();

	public:  // Functions from base classes

		/**
		* From CCoeControl, Draw
		* Draw this CGfxDirectScreenBitmapView to the screen.
		* @param aRect the rectangle of this view that needs updating
		*/
		void Draw( const TRect& aRect ) const;
		void ProfileBitBlitL(TInt aTestNo);

		/**
		* From CoeControl, SizeChanged.
		* Called by framework when the view size is changed.
		*/
		virtual void SizeChanged();

	private: // Constructors

		/**
		* ConstructL
		* 2nd phase constructor.
		* Perform the second phase construction of a
		* CGfxDirectScreenBitmapView object.
		* @param aRect The rectangle this view will be drawn to.
		*/
		void ConstructL(const TRect& aRect);
		void CreateLogFileL();
		void CloseLogFile();
		/**
		* CGfxDirectScreenBitmapView.
		* C++ default constructor.
		*/
		CGfxBitBlitView();
private:
		RFile	iLogFile;
		CGfxTimer* iTimer;
		TInt iCurrentTest;
	};

#endif // __GFXWORKBENCHAPPVIEW_h__

// End of File
