/*
Copyright (c) 2002-2011 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: Declares view class for application.
*/  


#ifndef __GFXICLVIEW_h__
#define __GFXICLVIEW_h__

// INCLUDES
#include <coecntrl.h>

class MGfxImageDecoderHandler
	{
public:
	virtual void GfxImageLoadedCallBack(TInt aError) = 0;	
	};
	
class CGfxImageDecoder;

// CLASS DECLARATION
class CGfxIclView : public CCoeControl, public MGfxImageDecoderHandler
	{
	public: // New methods

		/**
		* NewL.
		* Two-phased constructor.
		* Create a CGfxDirectScreenView object, which will draw itself to aRect.
		* @param aRect The rectangle this view will be drawn to.
		* @return a pointer to the created instance of CGfxDirectScreenView.
		*/
		static CGfxIclView* NewL( const TRect& aRect );

		/**
		* NewLC.
		* Two-phased constructor.
		* Create a CGfxDirectScreenView object, which will draw itself
		* to aRect.
		* @param aRect Rectangle this view will be drawn to.
		* @return A pointer to the created instance of CGfxDirectScreenView.
		*/
		static CGfxIclView* NewLC( const TRect& aRect );

		/**
		* ~CGfxDirectScreenView
		* Virtual Destructor.
		*/
		virtual ~CGfxIclView();
	
	public:
		void StartL();
		void StopL();

	public:  // Functions from base classes

		/**
		* From CCoeControl, Draw
		* Draw this CGfxDirectScreenView to the screen.
		* @param aRect the rectangle of this view that needs updating
		*/
		void Draw( const TRect& aRect ) const;

		/**
		* From CoeControl, SizeChanged.
		* Called by framework when the view size is changed.
		*/
		virtual void SizeChanged();
		
		virtual void GfxImageLoadedCallBack(TInt aError);

	private: // Constructors

		/**
		* ConstructL
		* 2nd phase constructor.
		* Perform the second phase construction of a
		* CGfxDirectScreenView object.
		* @param aRect The rectangle this view will be drawn to.
		*/
		void ConstructL(const TRect& aRect);

		/**
		* CGfxDirectScreenView.
		* C++ default constructor.
		*/
		CGfxIclView();

private:
	CFbsBitmap* iBitmap;
	CFbsBitmap* iLoadingBmp;	
	CGfxImageDecoder* iImageDecoder;
	};

#endif // __GFXICLVIEW_h__

// End of File
