/*
Copyright (c) 2002-2011 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/ 
#ifndef GFXVIDEOPLAYER_H_
#define GFXVIDEOPLAYER_H_

#include <VideoPlayer.h>
#include <COECNTRL.H>

class CVideoPlayerControl;
class CGfxVideoPlayer : public CBase ,public MVideoPlayerUtilityObserver
	{
public:  
	CGfxVideoPlayer ();
	void ConstructL(CVideoPlayerControl* aView);
	static CGfxVideoPlayer * NewL(CVideoPlayerControl* aView );
	~CGfxVideoPlayer();
	
// from MVideoPlayerUtilityObserver
public:
	void MvpuoOpenComplete(TInt aError);
	void MvpuoPrepareComplete(TInt aError);
	void MvpuoFrameReady(CFbsBitmap& aFrame,TInt aError);
	void MvpuoPlayComplete(TInt aError);
	void MvpuoEvent(const TMMFEvent& aEvent);
	
public:
	void InitControllerL(); 
	void PauseL();
	TTimeIntervalMicroSeconds PositionL() ;
	TTimeIntervalMicroSeconds DurationL() ;
	void Stop();

private:
	CVideoPlayerUtility*	iPlayer;
	CVideoPlayerControl*	iView;
 	};

/*
 * CVideoPlayerControl - A control which uses CGfxVideoPlayer to render to a window
 */
class CVideoPlayerControl : public CCoeControl
    {
public:
	static CVideoPlayerControl* NewL(const TRect& aRect); 
	static CVideoPlayerControl* NewLC(const TRect& aRect);
	void ConstructL(const TRect& aRect);
	CVideoPlayerControl();
	~CVideoPlayerControl();

	void StartL();
	void StopL();
	
public:
	void SignalError(const TDesC& aCallBack, TInt aErrorCode);
	
public:  
	void Draw(const TRect& aRect) const;
	inline RWindow& ClientWindow();
	inline TRect VideoRect() const;
	inline RWsSession& ClientWsSession();
	inline CWsScreenDevice& ScreenDevice();
private:
	TRect iVideoRect;
	CGfxVideoPlayer* iPlayer;
    };

#endif /*GFXVIDEOPLAYER_H_*/
