/*
Copyright (c) 2002-2011 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: Application view implementation
*/



// INCLUDE FILES
#include <coemain.h>
#include <EIKENV.H>
#include "GfxDirectScreenView.h"
#include "CGfxDirectAccess.h"
#include "GfxVideoPlayer.h"

// ============================ MEMBER FUNCTIONS ===============================

// -----------------------------------------------------------------------------
// CGfxDirectScreenView::NewL()
// Two-phased constructor.
// -----------------------------------------------------------------------------
//
CGfxDirectScreenView* CGfxDirectScreenView::NewL( const TRect& aRect )
	{
	CGfxDirectScreenView* self = CGfxDirectScreenView::NewLC( aRect );
	CleanupStack::Pop( self );
	return self;
	}

// -----------------------------------------------------------------------------
// CGfxDirectScreenView::NewLC()
// Two-phased constructor.
// -----------------------------------------------------------------------------
//
CGfxDirectScreenView* CGfxDirectScreenView::NewLC( const TRect& aRect )
	{
	CGfxDirectScreenView* self = new ( ELeave ) CGfxDirectScreenView;
	CleanupStack::PushL( self );
	self->ConstructL( aRect );
	return self;
	}

// -----------------------------------------------------------------------------
// CGfxDirectScreenView::ConstructL()
// Symbian 2nd phase constructor can leave.
// -----------------------------------------------------------------------------
//
void CGfxDirectScreenView::ConstructL( const TRect& aRect )
	{
	// Create a window for this application view
	CreateWindowL();

	// Set the windows size
	SetRect( aRect );


	// Activate the window, which makes it ready to be drawn
	ActivateL();
	}

// -----------------------------------------------------------------------------
// CGfxDirectScreenView::CGfxDirectScreenView()
// C++ default constructor can NOT contain any code, that might leave.
// -----------------------------------------------------------------------------
//
CGfxDirectScreenView::CGfxDirectScreenView()
	{
	// No implementation required
	}


// -----------------------------------------------------------------------------
// CGfxDirectScreenView::~CGfxDirectScreenView()
// Destructor.
// -----------------------------------------------------------------------------
//
CGfxDirectScreenView::~CGfxDirectScreenView()
	{
	// No implementation required
	delete iDirectDisplay;
	}


// -----------------------------------------------------------------------------
// CGfxDirectScreenView::Draw()
// Draws the display.
// -----------------------------------------------------------------------------
//
void CGfxDirectScreenView::Draw( const TRect& /*aRect*/ ) const
	{
	// Get the standard graphics context
	/*CWindowGc& gc = SystemGc();

	// Gets the control's extent
	TRect drawRect( Rect());

	// Clears the screen
	gc.Clear( drawRect );
	*/
	}

// -----------------------------------------------------------------------------
// CGfxDirectScreenView::SizeChanged()
// Called by framework when the view size is changed.
// -----------------------------------------------------------------------------
//
void CGfxDirectScreenView::SizeChanged()
	{  
	DrawNow();
	}
// End of File

void CGfxDirectScreenView::StartL(TBool aGcMode)
	{
	
	const TRect dsaRect =  TRect(PositionRelativeToScreen(),Size());
    
	  // Set up direct displayer for life engine
    iDirectDisplay = new (ELeave) CGfxDirectAccess (
        iEikonEnv->WsSession(),      // Window server session
        Window(),dsaRect,aGcMode          // The window itself
        );
    iDirectDisplay -> ConstructL();
	
	iDirectDisplay->StartL();
	
	}
	
void CGfxDirectScreenView::StopL()
{
}
