/*
Copyright (c) 2002-2011 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/
#include "GfxVideoPlayer.h"

#include <EIKENV.H>

_LIT(KVideoFileName,"c:\\data\\video\\videotest.3gp");

CGfxVideoPlayer * CGfxVideoPlayer :: NewL(CVideoPlayerControl* aView)
{
     CGfxVideoPlayer * self = new (ELeave) CGfxVideoPlayer ();
     CleanupStack::PushL( self);
     self->ConstructL(aView );
     CleanupStack::Pop();
     return self;
    }
void CGfxVideoPlayer ::ConstructL(CVideoPlayerControl* aView)
   {
    iView = aView;
   }
CGfxVideoPlayer ::CGfxVideoPlayer ():iPlayer(NULL)
   {
 
   }
CGfxVideoPlayer ::~CGfxVideoPlayer ()
   {
	delete iPlayer, iPlayer = NULL;	
    }
 
void CGfxVideoPlayer ::InitControllerL()   
    {
     iPlayer = NULL;
     iPlayer = CVideoPlayerUtility::NewL(*this,EMdaPriorityNormal,
                                        EMdaPriorityPreferenceNone,
	                                iView->ClientWsSession(),
                     			iView->ScreenDevice(),
					iView->ClientWindow(),
					iView->VideoRect(),
					iView->VideoRect() );
     iPlayer->OpenFileL( KVideoFileName);
    }
void CGfxVideoPlayer ::MvpuoPrepareComplete(TInt aError)
    {
    if(aError)
    	iView->SignalError(_L("MvpuoPrepareComplete"), aError);
    else
    	iPlayer->Play();
    }	
void CGfxVideoPlayer ::MvpuoEvent(const TMMFEvent& /*aEvent*/)
    {
     // do nothing..

    }
void CGfxVideoPlayer ::MvpuoPlayComplete(TInt aError)
    {
    if(aError)
    	iView->SignalError(_L("MvpuoPlayComplete"), aError);
    }
void CGfxVideoPlayer ::MvpuoFrameReady(CFbsBitmap& /*aFrame*/,TInt aError)
	{
    if(aError)
    	iView->SignalError(_L("MvpuoFrameReady"), aError);
    }
void CGfxVideoPlayer ::MvpuoOpenComplete(TInt aError)
	{
    if(aError)
    	iView->SignalError(_L("MvpuoOpenComplete"), aError);
    else
    	iPlayer->Prepare();
    }
void CGfxVideoPlayer ::PauseL()
    {
     iPlayer->PauseL();
    }
TTimeIntervalMicroSeconds  CGfxVideoPlayer ::PositionL()
    {
     return iPlayer->PositionL();
    }
TTimeIntervalMicroSeconds CGfxVideoPlayer ::DurationL()
    {
     return iPlayer->DurationL();
    }
void CGfxVideoPlayer ::Stop()
    {
     iPlayer->Stop();
    }

CVideoPlayerControl* CVideoPlayerControl::NewL(const TRect& aRect)
    {
     CVideoPlayerControl* self = CVideoPlayerControl::NewLC(aRect);
     CleanupStack::Pop(self);
     return self;
    }
CVideoPlayerControl* CVideoPlayerControl::NewLC(const TRect& aRect)
    {
     CVideoPlayerControl* self = new (ELeave) CVideoPlayerControl;
     CleanupStack::PushL(self); 
     self->ConstructL(aRect);
     return self;
    }

CVideoPlayerControl::CVideoPlayerControl()
    {
     // no implementation required
    }
CVideoPlayerControl::~CVideoPlayerControl()
    {
    if(iPlayer)
    	iPlayer->Stop();
    delete iPlayer;
    }
void CVideoPlayerControl::ConstructL(const TRect& aRect)
    {
    iPlayer = CGfxVideoPlayer::NewL(this);

	CreateWindowL();
	SetRect(aRect);
	iVideoRect = Rect();
	TPoint point = PositionRelativeToScreen();
	iVideoRect.Move(point);
	ActivateL();
    }

void CVideoPlayerControl::StartL()
	{
	iPlayer->InitControllerL();
	}

void CVideoPlayerControl::StopL()
	{
	iPlayer->Stop();
	}
	
void CVideoPlayerControl::SignalError(const TDesC& aCallBack, TInt aErrorCode)
	{
	TBuf<10> errorString;
	errorString.AppendNum(aErrorCode);
	
	iEikonEnv->AlertWin(aCallBack, errorString);
	}

void CVideoPlayerControl::Draw(const TRect& /*aRect*/) const
    {
     CWindowGc& gc = SystemGc();
     //gc.SetBrushColor(KRgbBlack);
     gc.SetBrushColor(KRgbTransparent);
     gc.SetBrushStyle (CGraphicsContext::ESolidBrush);
     TRect rect = Rect();
     gc.Clear(rect);
    }
 
inline RWindow& CVideoPlayerControl::ClientWindow()
    {
     return Window();
    }
inline TRect CVideoPlayerControl::VideoRect() const
    {
     return iVideoRect;
    }
inline RWsSession& CVideoPlayerControl::ClientWsSession()
    {
     return ControlEnv()->WsSession();
    }
inline CWsScreenDevice& CVideoPlayerControl::ScreenDevice()
    {
     return *(ControlEnv()->ScreenDevice());
    }
